@@ -1,31 +1,9 @@
 #!/usr/bin/env python
 #
-# Copyright 2016 by Shaheed Haque (srhaque@theiet.org)
-# Copyright 2016 by Stephen Kelly (steveire@gmail.com)
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-# 3. The name of the author may not be used to endorse or promote products
-#    derived from this software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# SPDX-FileCopyrightText: 2016 Shaheed Haque <srhaque@theiet.org>
+# SPDX-FileCopyrightText: 2016 Stephen Kelly <steveire@gmail.com>
 #
+# SPDX-License-Identifier: BSD-3-Clause
 
 """SIP file generator for PyQt."""
 
@@ -39,7 +17,7 @@ import re
 import sys
 import traceback
 from clang import cindex
-from clang.cindex import AccessSpecifier, CursorKind, SourceRange, StorageClass, TokenKind, TypeKind, TranslationUnit
+from clang.cindex import AccessSpecifier, AvailabilityKind, CursorKind, SourceRange, StorageClass, TokenKind, TypeKind, TranslationUnit
 
 import rules_engine
 
@@ -210,6 +188,7 @@ class SipGenerator(object):
         base_specifiers = []
         template_type_parameters = []
         had_copy_constructor = False
+        had_deleted_copy_constructor = False;
         had_const_member = False
         for member in container.get_children():
             #
@@ -291,7 +270,13 @@ class SipGenerator(object):
                     numParams += 1
                 return numParams == 0
 
-            had_copy_constructor = had_copy_constructor or is_copy_constructor(member)
+            if is_copy_constructor(member):
+                had_copy_constructor = True
+                # We need to generate a fake private copy constructor for deleted constructors
+                if member.availability == AvailabilityKind.NOT_AVAILABLE and member.access_specifier != AccessSpecifier.PRIVATE:
+                    had_deleted_copy_constructor = True
+                    continue
+
             #
             # Discard almost anything which is private.
             #
@@ -364,7 +349,7 @@ class SipGenerator(object):
             #
             # Generate private copy constructor for non-copyable types.
             #
-            if had_const_member and not had_copy_constructor:
+            if (had_deleted_copy_constructor) or (had_const_member and not had_copy_constructor):
                 body += "    private:\n        {}(const {} &); // Generated\n".format(name, container.type.get_canonical().spelling)
             #
             # Flesh out the SIP context for the rules engine.
@@ -763,7 +748,7 @@ def main(argv=None):
     """
     Take a single C++ header file and generate the corresponding SIP file.
     Beyond simple generation of the SIP file from the corresponding C++
-    header file, a set of rules can be used to customise the generated
+    header file, a set of rules can be used to customize the generated
     SIP file.
 
     Examples:
